import pandas as pd
import requests

def student_scores(id, submission):
    url = f"https://ai-grader-ihcwj2lvaq-as.a.run.app/student/id?id={id}&submission={submission}"
    response = requests.get(url)
    data = response.json()

    if 'error' in data:
        print(data['error'])
        return None

    try:
        student_info = data['student']
        student_general_info = {k: student_info[k] for k in student_info if k not in ['scores', 'unix_id']}
        scores = student_info['scores']
        scores_good = [score for score in scores if int(score['score']) >= 0]
        df_scores = pd.DataFrame(scores_good)

        for key, value in student_general_info.items():
            print(f"{key}: {value}")
        
        return df_scores

    except KeyError:
        print("Student not found")
        return None


import requests
import io
from PIL import Image

CONVEX_SUBMIT_URL = 'https://astute-rat-865.convex.site/submit'

def submit(id_student, name, assignment_name, result, batch, question_name='', code=''):
    data = {
        "studentId": id_student,
        "studentName": name,
        "assignmentName": assignment_name,
        "questionName": question_name,
        "batch": batch,
        "code": code,
        "result": str(result)
    }

    try:
        r = requests.post(CONVEX_SUBMIT_URL, json=data)
        if r.status_code == 200:
            try:
                response_data = r.json()
                if 'score' in response_data and response_data['score'] is not None:
                    return f'Assignment successfully submitted. Score: {response_data["score"]}'
            except:
                pass
            return 'Assignment successfully submitted'
        else:
            return f'Failed to submit assignment: {r.text}'
    except Exception as e:
        return f'Error submitting assignment: {str(e)}'

def submit_image(id_student, name, assignment_name, question_name, batch, image_path):
    try:
        # Prepare data fields
        data = {
            "studentId": id_student,
            "studentName": name,
            "assignmentName": assignment_name,
            "questionName": question_name,
            "batch": batch,
        }

        # Prepare image file
        # We open the image to ensure it's valid and maybe resize/convert if needed in future
        # For now just re-saving to bytes to ensure clean upload
        image = Image.open(image_path).convert('RGB')
        image_byte_arr = io.BytesIO()
        image.save(image_byte_arr, format='JPEG')
        image_byte_arr.seek(0)

        files = {
            'image': ('submission.jpg', image_byte_arr, 'image/jpeg')
        }

        r = requests.post(CONVEX_SUBMIT_URL, data=data, files=files)
        
        if r.status_code == 200:
            try:
                response_data = r.json()
                if 'score' in response_data and response_data['score'] is not None:
                    return f'Assignment successfully submitted. Score: {response_data["score"]}'
            except:
                pass
            return 'Assignment successfully submitted'
        else:
            return f'Failed to submit assignment: {r.text}'
            
    except Exception as e:
        return f'Error submitting assignment: {str(e)}'


from setuptools import setup, find_packages

with open("README_PYPI.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="rggrader2",
    version="0.1.2",
    author="Ruangguru AI Team",
    author_email="ai@ruangguru.com",
    description="Submission tool for Ruangguru AI Bootcamp",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/ruang-guru/ai-grader",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    install_requires=[
        "requests",
        "Pillow",
        "pandas"
    ],
)
